# Generated by Django 5.0.7 on 2024-08-14 19:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0055_alter_agent_style_icon"),
    ]

    operations = [
        migrations.AddField(
            model_name="chatmodeloptions",
            name="vision_enabled",
            field=models.BooleanField(default=False),
        ),
    ]
