# Generated by Django 5.0.13 on 2025-03-23 04:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0086_alter_texttoimagemodelconfig_model_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aimodelapi",
            name="api_key",
            field=models.CharField(max_length=4000),
        ),
    ]
