# Generated by Django 5.0.7 on 2024-08-05 11:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0054_alter_agent_style_color"),
    ]

    operations = [
        migrations.AlterField(
            model_name="agent",
            name="style_icon",
            field=models.CharField(
                choices=[
                    ("Lightbulb", "Lighbulb"),
                    ("Health", "Health"),
                    ("Robot", "Robot"),
                    ("Aperture", "Aperture"),
                    ("GraduationCap", "Graduation Cap"),
                    ("Jeep", "Jeep"),
                    ("Island", "Island"),
                    ("MathOperations", "Math Operations"),
                    ("Asclepius", "Asclepius"),
                    ("Couch", "Couch"),
                    ("Code", "Code"),
                    ("Atom", "Atom"),
                    ("ClockCounterClockwise", "Clock Counter Clockwise"),
                    ("PencilLine", "Pencil Line"),
                    ("Chalkboard", "Chalkboard"),
                ],
                default="Lightbulb",
                max_length=200,
            ),
        ),
    ]
