# Generated by Django 5.0.10 on 2025-01-15 11:05

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0079_searchmodelconfig_embeddings_inference_endpoint_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="speechtotextmodeloptions",
            name="ai_model_api",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="database.aimodelapi",
            ),
        ),
    ]
