# Generated by Django 5.0.7 on 2024-08-16 18:09

from typing import List

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0056_chatmodeloptions_vision_enabled"),
        ("database", "0056_searchmodelconfig_cross_encoder_model_config"),
    ]
    operations: List[migrations.operations.base.Operation] = []
